@@ -5,10 +5,12 @@ module Codec.Compression.BZip ( -- * High-level functions.
                                 compress
                               , compressWith
                               , decompress
-                              -- * Low-level bindings
-                              , module Codec.Compression.BZip.Foreign
+                              -- * Errors
+                              , BZError (..)
+                              -- * Miscellany
+                              , bZ2BzlibVersion
                               ) where
 
-import           Codec.Compression.BZip.Foreign
+import           Codec.Compression.BZip.Foreign.Common
 import           Codec.Compression.BZip.Pack
 import           Codec.Compression.BZip.Unpack
